==> haskell-wai-websockets-3.0.1.1-39-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wai-websockets.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-websockets
version: 3.0.1.1
id: wai-websockets-3.0.1.1-LhSwPTYaI3rKypxD6wSDBS
key: wai-websockets-3.0.1.1-LhSwPTYaI3rKypxD6wSDBS
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: Provide a bridge between WAI and the websockets package.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-websockets>.
category: Web, Yesod
author: Michael Snoyman, Jasper Van der Jeugt, Ting-Yen Lai
exposed: True
indefinite: False
exposed-modules:
    Network.Wai.Handler.WebSockets
abi: 953c981b588241d4260d35ebb7580da2
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/wai-websockets-3.0.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/wai-websockets-3.0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/wai-websockets-3.0.1.1
hs-libraries: HSwai-websockets-3.0.1.1-LhSwPTYaI3rKypxD6wSDBS
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    wai-3.2.1.1-12WuVnNjQfQ3f2A19Ra0dE
    blaze-builder-0.4.0.2-DHYoGQYzHva8PydFQisCY7
    case-insensitive-1.2.0.10-AWseT79MXu13ZYpcQBCANd
    network-2.6.3.3-BsPhUcUvmHlbFKWY24Oor transformers-0.5.2.0
    websockets-0.12.3.1-GzhHOtMAMLgKtRhEpBkuFc
    http-types-0.9.1-4ZIPDJugy3GJAtyWZ0RpKv
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             wai-3.2.1.1-12WuVnNjQfQ3f2A19Ra0dE=73d1afed3c80663ac957a99a7f1e4642
             blaze-builder-0.4.0.2-DHYoGQYzHva8PydFQisCY7=4ded867b3c298ec132dad2104a7f7b70
             case-insensitive-1.2.0.10-AWseT79MXu13ZYpcQBCANd=d2a631059bf8ed4631eaacfed742cab7
             network-2.6.3.3-BsPhUcUvmHlbFKWY24Oor=f013b5448241bfbc78fb9f4b90b2582b
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             websockets-0.12.3.1-GzhHOtMAMLgKtRhEpBkuFc=b49abeedbec4a82111f2d385bad86410
             http-types-0.9.1-4ZIPDJugy3GJAtyWZ0RpKv=b80836ab18bdd54a07dfb2450d10ef5b
haddock-interfaces: /usr/share/doc/haskell-wai-websockets/html/wai-websockets.haddock
haddock-html: /usr/share/doc/haskell-wai-websockets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-websockets-3.0.1.1-40-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wai-websockets.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-websockets
version: 3.0.1.1
id: wai-websockets-3.0.1.1-7YFx3RX9XttDLuJIm0oLyi
key: wai-websockets-3.0.1.1-7YFx3RX9XttDLuJIm0oLyi
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: Provide a bridge between WAI and the websockets package.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-websockets>.
category: Web, Yesod
author: Michael Snoyman, Jasper Van der Jeugt, Ting-Yen Lai
exposed: True
indefinite: False
exposed-modules:
    Network.Wai.Handler.WebSockets
abi: 03e8ddb1ecdd4934641a21498f103824
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/wai-websockets-3.0.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/wai-websockets-3.0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/wai-websockets-3.0.1.1
hs-libraries: HSwai-websockets-3.0.1.1-7YFx3RX9XttDLuJIm0oLyi
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    wai-3.2.1.1-12WuVnNjQfQ3f2A19Ra0dE
    blaze-builder-0.4.0.2-DHYoGQYzHva8PydFQisCY7
    case-insensitive-1.2.0.10-AWseT79MXu13ZYpcQBCANd
    network-2.6.3.3-BsPhUcUvmHlbFKWY24Oor transformers-0.5.2.0
    websockets-0.12.3.1-1egcVUx3VIS4oBuHygrtPq
    http-types-0.9.1-4ZIPDJugy3GJAtyWZ0RpKv
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             wai-3.2.1.1-12WuVnNjQfQ3f2A19Ra0dE=73d1afed3c80663ac957a99a7f1e4642
             blaze-builder-0.4.0.2-DHYoGQYzHva8PydFQisCY7=4ded867b3c298ec132dad2104a7f7b70
             case-insensitive-1.2.0.10-AWseT79MXu13ZYpcQBCANd=d2a631059bf8ed4631eaacfed742cab7
             network-2.6.3.3-BsPhUcUvmHlbFKWY24Oor=f013b5448241bfbc78fb9f4b90b2582b
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             websockets-0.12.3.1-1egcVUx3VIS4oBuHygrtPq=7accbf093d1b9462f3f51d500a0a7fa5
             http-types-0.9.1-4ZIPDJugy3GJAtyWZ0RpKv=b80836ab18bdd54a07dfb2450d10ef5b
haddock-interfaces: /usr/share/doc/haskell-wai-websockets/html/wai-websockets.haddock
haddock-html: /usr/share/doc/haskell-wai-websockets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
